==> dde-launchpad_1.0.11.tar.xz: BUILD/translations/dde-launchpad_de_DE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Oben anheften</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Nach oben schieben</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Aus den Favoriten entfernen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Zu den Favoriten hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Am Schreibtisch ablegen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Vom Schreibtisch entfernen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Aus dem Dock entfernen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Zum Dock hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Zu den Startobjekten hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Aus den Startobjekten entfernen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Proxy benutzen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Bildschirmanzeigenskalierung ausschalten</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Deinstallieren</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation>Ausschalten</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="56"/>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="103"/>
        <source>Full-screen Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Häufig benutzt</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="152"/>
        <source>Window Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Zeige Starter (standardmäßig ausgeblendet)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Starteranzeige umschalten</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation>Spiel</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Büro</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Lesen</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Entwicklung</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Anderes</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="411"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Sind Sie sicher, dass Sie %1 deinstallieren wollen?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="423"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="437"/>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>kürzlich installiert</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Alle Apps</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="545"/>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Eigene Sortierung</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Sortierung nach Kategorie</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Sortierung nach Namen</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Dokumente</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Schreibtisch</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Kontrollzentrum</translation>
    </message>
</context>
</TS>

==> dde-launchpad_2.0.4.tar.xz: BUILD/translations/dde-launchpad_de_DE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Oben anheften</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Nach oben schieben</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Aus den Favoriten entfernen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Zu den Favoriten hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Am Schreibtisch ablegen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Vom Schreibtisch entfernen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Aus dem Dock entfernen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Zum Dock hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Zu den Startobjekten hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Aus den Startobjekten entfernen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Proxy benutzen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Bildschirmanzeigenskalierung ausschalten</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Deinstallieren</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="33"/>
        <source>Power</source>
        <translation>Ausschalten</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="62"/>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="109"/>
        <source>Full-screen Mode</source>
        <translation>Vollbild-Modus</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Installieren</translation>
    </message>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Häufig benutzt</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="163"/>
        <source>Window Mode</source>
        <translation>Fenster-Modus</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="21"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Zeige Starter (standardmäßig ausgeblendet)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="22"/>
        <source>Toggle launcher visibility</source>
        <translation>Starteranzeige umschalten</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Games</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Büro</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Lesen</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Entwicklung</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Anderes</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="400"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Sind Sie sicher, dass Sie %1 deinstallieren wollen?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="412"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="426"/>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>kürzlich installiert</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Alle Apps</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <location filename="../qml/FullscreenFrame.qml" line="556"/>
        <source>No search results</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Eigene Sortierung</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Sortierung nach Kategorie</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Sortierung nach Namen</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Sortierreihenfolge</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Dokumente</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Schreibtisch</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Kontrollzentrum</translation>
    </message>
</context>
</TS>
